@@ -1,5 +1,5 @@
 /* HomeBank -- Free easy personal accounting for all !
- * Copyright (C) 1995-2006 Maxime DOYEN
+ * Copyright (C) 1995-2007 Maxime DOYEN
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -148,7 +148,6 @@ char buf[G_ASCII_DTOSTR_BUF_SIZE];
 
 
 
-//todo amiga/linux
 static void defbudget_load_csv( GtkWidget *widget, gpointer user_data)
 {
 struct defbudget_data *data;
@@ -680,7 +679,7 @@ guint i, row;
 
 	gtk_dialog_set_has_separator(GTK_DIALOG (window), FALSE);
 	
-	gtk_window_set_icon_from_file(GTK_WINDOW (window), PIXMAPS_DIR "/budget.svg", NULL);
+	homebank_window_set_icon_from_file(GTK_WINDOW (window), "budget.svg");
 
 	//store our window private data
 	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)&data);
