@@ -1,5 +1,5 @@
 /* HomeBank -- Free easy personal accounting for all !
- * Copyright (C) 1995-2006 Maxime DOYEN
+ * Copyright (C) 1995-2007 Maxime DOYEN
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 
 #include "homebank.h"
-
+#include "preferences.h"
 
 /* our global datas */
 extern struct HomeBank *GLOBALS;
@@ -41,6 +41,7 @@ extern GdkPixbuf *paymode_icons[];
     gint sortcol = GPOINTER_TO_INT(userdata);
     gint ret = 0;
 	Operation *ope1, *ope2;
+	gdouble tmpval = 0;
 
 	gtk_tree_model_get(model, a, LST_DSPOPE_DATAS, &ope1, -1);
 	gtk_tree_model_get(model, b, LST_DSPOPE_DATAS, &ope2, -1);
@@ -68,9 +69,11 @@ extern GdkPixbuf *paymode_icons[];
 				ret = g_utf8_collate(ope1->wording, ope2->wording);
 			break;
 
+		case LST_DSPOPE_AMOUNT:
 		case LST_DSPOPE_EXPENSE:
 		case LST_DSPOPE_INCOME:
-			ret = (gint)ope1->amount - ope2->amount;
+			tmpval = ope1->amount - ope2->amount;
+			ret = tmpval > 0 ? 1 : -1;
 			break;
 
 		case LST_DSPOPE_CATEGORY:
@@ -134,7 +137,7 @@ GDate *date;
 	gtk_tree_model_get(model, iter, LST_DSPOPE_DATAS, &ope, -1);
 
 	date = g_date_new_julian (ope->date);
-	g_date_strftime (buffer, 256-1, "%x", date);
+	g_date_strftime (buffer, 256-1, PREFS->date_format, date);
 	g_date_free(date);
 
 	//g_snprintf(buf, sizeof(buf), "%d", ope->ope_Date);
@@ -200,9 +203,9 @@ gint type;
 	// get the operation
 	gtk_tree_model_get(model, iter, LST_DSPOPE_DATAS, &ope, -1);
 
-	type = (ope->flags & OF_INCOME) ? 1 : -1;
+	type = (ope->flags & OF_INCOME) ? LST_DSPOPE_INCOME : LST_DSPOPE_EXPENSE;
 
-	if( !(ope->amount) || (column != type) )
+	if( !(ope->amount) || (column != type) && column != LST_DSPOPE_AMOUNT )
 	{
 		g_object_set(renderer, "markup", NULL, NULL);
 	}
@@ -222,7 +225,7 @@ gint type;
 		else
 			minor = 0;
 
-		hb_strfmon(buf, 127, ope->amount, minor);
+		mystrfmon(buf, 127, ope->amount, minor);
 
 		color = (ope->flags & OF_INCOME) ? PREFS->color_inc : PREFS->color_exp;
 		markuptxt = g_strdup_printf("<span color='#%06x'>%s</span>", color, buf);
@@ -252,10 +255,137 @@ Category *grp;
 }
 
 
+
+
+/* column 3: Infos */
+static GtkTreeViewColumn *info_list_operation_column()
+{
+GtkTreeViewColumn  *column;
+GtkCellRenderer    *renderer;
+
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_column_set_title(column, _("Info"));
+
+	renderer = gtk_cell_renderer_pixbuf_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_info_cell_data_function, (gpointer)1, NULL);
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_info_cell_data_function, (gpointer)2, NULL);
+	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_INFO);
+	//gtk_tree_view_column_set_resizable(column, TRUE);
+
+	return column;
+}
+
+
+/* column 4: Payee */
+static GtkTreeViewColumn *payee_list_operation_column()
+{
+GtkTreeViewColumn  *column;
+GtkCellRenderer    *renderer;
+
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_column_set_title(column, _("Payee"));
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_payee_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_PAYEE);
+	gtk_tree_view_column_set_resizable(column, TRUE);
+
+	return column;
+}
+
+/* column 5: Wording */
+static GtkTreeViewColumn *wording_list_operation_column()
+{
+GtkTreeViewColumn  *column;
+GtkCellRenderer    *renderer;
+
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_column_set_title(column, _("Wording"));
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_wording_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_WORDING);
+	gtk_tree_view_column_set_resizable(column, TRUE);
+
+	return column;
+}
+
+
+
+
+/* column 6/7: Amount/Expense/Income */
+
+static GtkTreeViewColumn *amount_list_operation_column(gchar *title, gint id)
+{
+GtkTreeViewColumn  *column;
+GtkCellRenderer    *renderer;
+
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_column_set_title(column, title);
+	renderer = gtk_cell_renderer_text_new ();
+	g_object_set(renderer, "xalign", 1.0, NULL);
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_amount_cell_data_function, (gpointer)id, NULL);
+	gtk_tree_view_column_set_alignment (column, 1.0);
+	gtk_tree_view_column_set_sort_column_id (column, id);
+	gtk_tree_view_column_set_resizable(column, TRUE);
+
+	return column;
+}
+
+
+
+
+/* column 8: Category */
+static GtkTreeViewColumn *category_list_operation_column()
+{
+GtkTreeViewColumn  *column;
+GtkCellRenderer    *renderer;
+
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_column_set_title(column, _("Category"));
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_category_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_CATEGORY);
+	gtk_tree_view_column_set_resizable(column, TRUE);
+
+	return column;
+}
+
+
+
+void list_operation_visible_columns(GtkTreeView *treeview, gint *visibility)
+{
+GtkTreeViewColumn *column;
+GList *list, *tmp;
+gint i = 0, idx;
+
+	list = gtk_tree_view_get_columns( treeview );
+	tmp = g_list_first(list);
+	while (tmp != NULL)
+	{
+		column = tmp->data;
+		gtk_tree_view_column_set_visible (column, visibility[i]);
+		tmp = g_list_next(tmp);
+		i++;
+	}
+
+	g_list_free(list );
+}
+
+
+
+
 /*
 ** create our operation list
+** State, Date, Info, Payee, Wording, (Amount), Expense, Income, Category
 */
-GtkWidget *create_list_operation(void)
+GtkWidget *create_list_operation(gboolean *columns)
 {
 GtkListStore *store;
 GtkWidget *view;
@@ -273,6 +403,7 @@ GtkTreeViewColumn  *column;
 		G_TYPE_BOOLEAN,
 		G_TYPE_BOOLEAN,
 		G_TYPE_BOOLEAN,
+		G_TYPE_BOOLEAN,
 		G_TYPE_BOOLEAN
 		);
 
@@ -318,95 +449,47 @@ GtkTreeViewColumn  *column;
 	//gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
-	/* column 3: Infos */
-	column = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(column, _("Info"));
 
-	renderer = gtk_cell_renderer_pixbuf_new ();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_info_cell_data_function, (gpointer)1, NULL);
-
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_info_cell_data_function, (gpointer)2, NULL);
-	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_INFO);
-	//gtk_tree_view_column_set_resizable(column, TRUE);
+	column = info_list_operation_column();
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
-	/* column 4: Payee */
-	column = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(column, _("Payee"));
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_payee_cell_data_function, NULL, NULL);
-	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_PAYEE);
-	//gtk_tree_view_column_set_resizable(column, TRUE);
+	column = payee_list_operation_column();
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
-	/* column 5: Wording */
-	column = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(column, _("Wording"));
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_wording_cell_data_function, NULL, NULL);
-	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_WORDING);
-	//gtk_tree_view_column_set_resizable(column, TRUE);
+	column = wording_list_operation_column();
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
-	/* column 6: Expense */
-	column = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(column, _("Expense"));
-	renderer = gtk_cell_renderer_text_new ();
-	g_object_set(renderer, "xalign", 1.0, NULL);
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_amount_cell_data_function, (gpointer)-1, NULL);
-	gtk_tree_view_column_set_alignment (column, 1.0);
-	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_EXPENSE);
-	//gtk_tree_view_column_set_resizable(column, TRUE);
+	column = amount_list_operation_column(_("Amount"), LST_DSPOPE_AMOUNT);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
-	/* column 7: Income */
-	column = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(column, _("Income"));
-	renderer = gtk_cell_renderer_text_new ();
-	g_object_set(renderer, "xalign", 1.0, NULL);
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_amount_cell_data_function, (gpointer)1, NULL);
-	gtk_tree_view_column_set_alignment (column, 1.0);
-	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_INCOME);
-	//gtk_tree_view_column_set_resizable(column, TRUE);
+	column = amount_list_operation_column(_("Expense"), LST_DSPOPE_EXPENSE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
-	/* column 8: Category */
-	column = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(column, _("Category"));
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_category_cell_data_function, NULL, NULL);
-	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_CATEGORY);
-	//gtk_tree_view_column_set_resizable(column, TRUE);
+	column = amount_list_operation_column(_("Income"), LST_DSPOPE_INCOME);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+
+	column = category_list_operation_column();
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
   /* column 9: empty */
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
-	/* sort */
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_DATE, ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_DATE), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_INFO, ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_INFO), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_PAYEE, ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_PAYEE), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_WORDING, ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_WORDING), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_EXPENSE, ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_EXPENSE), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_INCOME, ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_INCOME), NULL);
+  /* sort */
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_DATE    , ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_DATE), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_INFO    , ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_INFO), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_PAYEE   , ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_PAYEE), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_WORDING , ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_WORDING), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_AMOUNT  , ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_AMOUNT), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_EXPENSE , ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_EXPENSE), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_INCOME  , ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_INCOME), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_CATEGORY, ope_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_CATEGORY), NULL);
 
-    /* set initial sort order */
+  /* set initial sort order */
     gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), LST_DSPOPE_DATE, GTK_SORT_ASCENDING);
 
-
-
-
-
+  /* assign visibility */
+	list_operation_visible_columns(GTK_TREE_VIEW(view), columns);
 
 	return(view);
 }
@@ -414,7 +497,34 @@ GtkTreeViewColumn  *column;
 
 /* ---------------------------------------------- */
 
+/*
+** account cell function
+*/
+extern GList *ofx_acc_list;
 
+void ope_account_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{
+Operation *ope;
+Account *acc;
+gchar *name;
+
+	gtk_tree_model_get(model, iter, LST_DSPOPE_DATAS, &ope, -1);
+
+	name = NULL;
+	acc = g_list_nth_data(GLOBALS->acc_list, ope->account);
+	if( acc != NULL)
+		name = acc->name;
+	else
+	{
+		acc = g_list_nth_data(ofx_acc_list, ope->account - g_list_length(GLOBALS->acc_list) );
+		name = acc->name;
+
+		//debug
+		//g_print("get fromofx acc %d - %x - %s\n", ope->account - g_list_length(GLOBALS->acc_list), acc, acc->name);
+		//g_print("get fromofx acc %d - %x\n", ope->account - g_list_length(GLOBALS->acc_list), acc);
+	}
+	g_object_set(renderer, "text", name, NULL);
+}
 
 /*
 ** amount cell function
@@ -430,7 +540,7 @@ Operation *ope;
 	gchar *markuptxt;
 	guint32 color;
 
-		hb_strfmon(buf, 127, ope->amount, 0);
+		mystrfmon(buf, 127, ope->amount, 0);
 
 		color = (ope->flags & OF_INCOME) ? PREFS->color_inc : PREFS->color_exp;
 		markuptxt = g_strdup_printf("<span color='#%06x'>%s</span>", color, buf);
@@ -493,7 +603,7 @@ GtkTreeViewColumn  *column;
 
 	/* create list store */
 	store = gtk_list_store_new(
-	  	9,
+	  	8,
 		G_TYPE_POINTER,
 		G_TYPE_BOOLEAN,
 		G_TYPE_BOOLEAN,
@@ -501,7 +611,8 @@ GtkTreeViewColumn  *column;
 		G_TYPE_BOOLEAN,
 		G_TYPE_BOOLEAN,
 		G_TYPE_BOOLEAN,
-		G_TYPE_BOOLEAN,
+		//G_TYPE_BOOLEAN,
+		//G_TYPE_BOOLEAN,
 		G_TYPE_BOOLEAN
 		);
 
@@ -515,26 +626,40 @@ GtkTreeViewColumn  *column;
 
 	//gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), GTK_SELECTION_MULTIPLE);
 
-	/* column: Status */
-	column = gtk_tree_view_column_new();
-	gtk_tree_view_column_set_title(column, _("Duplicate"));
+	/* column: Selection */
+	renderer = gtk_cell_renderer_toggle_new ();
 
+	g_signal_connect (renderer, "toggled",
+		    G_CALLBACK (ope_importfixed_toggled), store);
+
+
+	column = gtk_tree_view_column_new_with_attributes (NULL,
+						     renderer,
+						     "active", LST_OPE_IMPTOGGLE,
+						     NULL);
+
+	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+
+	/* column: Duplicate */
+	column = gtk_tree_view_column_new();
+	//gtk_tree_view_column_set_title(column, _("Import ?"));
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_importstate_cell_data_function, NULL, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
-	/* column 5: Toggle */
-	renderer = gtk_cell_renderer_toggle_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Import ?"),
-						     renderer,
-						     "active", LST_OPE_IMPTOGGLE,
-						     NULL);
+//#ifndef NOOFX
+	/* column: Account */
+	column = gtk_tree_view_column_new();
+	gtk_tree_view_column_set_title(column, _("Account"));
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ope_account_cell_data_function, NULL, NULL);
+	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_DATE);
+	//gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
-	
-	g_signal_connect (renderer, "toggled",
-		    G_CALLBACK (ope_importfixed_toggled), store);
+//#endif	
 	
 	/* column: Date */
 	column = gtk_tree_view_column_new();
@@ -562,6 +687,7 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 	/* column: Payee */
+/*
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Payee"));
 	renderer = gtk_cell_renderer_text_new ();
@@ -570,7 +696,7 @@ GtkTreeViewColumn  *column;
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_PAYEE);
 	//gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
-
+*/
 	/* column: Wording */
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Wording"));
@@ -595,6 +721,7 @@ GtkTreeViewColumn  *column;
 
 
 	/* column : Category */
+/*
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Category"));
 	renderer = gtk_cell_renderer_text_new ();
@@ -603,7 +730,7 @@ GtkTreeViewColumn  *column;
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_CATEGORY);
 	//gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
-
+*/
 
 
 	/* column 6: empty */
